#
# spec file for package gpxsee
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           gpxsee
Version:        13.19
Release:        1.1
Summary:        GPS log file visualization and analysis tool
License:        GPL-3.0-only
Group:          Productivity/Graphics/Viewers
Url:            http://www.gpxsee.org
Source0:        https://github.com/tumic0/GPXSee/archive/%{version}/GPXSee-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  make
%if 0%{?centos_version} >= 800
BuildRequires:  gdb-headless
%endif
%if 0%{?fedora_version} || 0%{?centos_version} >= 800
BuildRequires:  qt5-qtbase
BuildRequires:  qt5-qtbase-gui
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-qtbase-private-devel
BuildRequires:  qt5-qtlocation-devel
BuildRequires:  qt5-qtsvg-devel
BuildRequires:  qt5-qtserialport-devel
BuildRequires:  qt5-linguist
Recommends: qt5-qtimageformats
Recommends: qt5-qtpbfimageformat
%else
%if 0%{?suse_version}
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Concurrent-devel
BuildRequires:  libQt5Gui-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5PrintSupport-devel
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libQt5Sql-devel
BuildRequires:  libQt5Svg-devel
BuildRequires:  libQt5SerialPort-devel
BuildRequires:  libqt5-qtlocation-devel
BuildRequires:  libqt5-linguist
Recommends: libQt5Sql5-sqlite
Recommends: libqt5-qtimageformats
Recommends: libqt5-qtpbfimageformat
%else
# Mageia
BuildRequires:  libqt5core-devel
BuildRequires:  libqt5gui-devel
BuildRequires:  libqt5concurrent-devel
BuildRequires:  libqt5widgets-devel
BuildRequires:  libqt5network-devel
BuildRequires:  libqt5printsupport-devel
BuildRequires:  libqt5opengl-devel
BuildRequires:  libqt5sql-devel
BuildRequires:  libqt5svg-devel
BuildRequires:  libqt5location-devel
BuildRequires:  libqt5serialport-devel
BuildRequires:  qttools5
Recommends: qtimageformats5
Recommends: libqt5-database-plugin-sqlite
Recommends: libqt5-qtpbfimageformat
%endif
%endif

%description
GPXSee is a Qt-based tool for visualizing and analyzing GPX, TCX, FIT, KML,
IGC, CUP, NMEA, SLF, SML, LOC, OziExplorer (PLT, RTE, WPT), Garmin GPI&CSV,
TomTom OV2&ITN, ONmove OMD/GHP and geotagged JPEG files.

%prep
%setup -q -n GPXSee-%{version}

%build
%if 0%{?suse_version}
lrelease-qt5 gpxsee.pro
%{qmake5} gpxsee.pro
%else
%if 0%{?fedora_version} || 0%{?centos_version} >= 800
lrelease-qt5 gpxsee.pro
%{qmake_qt5} gpxsee.pro
%else
lrelease gpxsee.pro
%{qmake_qt5} gpxsee.pro
%endif
%endif
make %{?_smp_mflags}

%install
install -d 755 %{buildroot}/%{_bindir}
install -d 755 %{buildroot}/%{_datadir}/applications
install -d 755 %{buildroot}/%{_datadir}/icons/hicolor
install -d 755 %{buildroot}/%{_datadir}/mime/packages
install -d 755 %{buildroot}/%{_datadir}/metainfo
install -d 755 %{buildroot}/%{_datadir}/%{name}
install -d 755 %{buildroot}/%{_datadir}/%{name}/maps
install -d 755 %{buildroot}/%{_datadir}/%{name}/CRS
install -d 755 %{buildroot}/%{_datadir}/%{name}/translations
install -d 755 %{buildroot}/%{_datadir}/%{name}/symbols
install -m 755 gpxsee %{buildroot}/%{_bindir}/%{name}
install -m 644 data/maps/* %{buildroot}/%{_datadir}/%{name}/maps
install -m 644 data/CRS/* %{buildroot}/%{_datadir}/%{name}/CRS
install -m 644 lang/*.qm %{buildroot}/%{_datadir}/%{name}/translations
install -m 644 icons/symbols/*.png %{buildroot}/%{_datadir}/%{name}/symbols
cp -r icons/app/hicolor/* %{buildroot}/%{_datadir}/icons/hicolor
install -m 644 pkg/linux/gpxsee.desktop %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -m 644 pkg/linux/gpxsee.xml %{buildroot}/%{_datadir}/mime/packages/%{name}.xml
install -m 644 pkg/linux/gpxsee.appdata.xml %{buildroot}/%{_datadir}/metainfo/%{name}.xml

%post
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%postun
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%files
%defattr(-,root,root)
%dir %{_datadir}/gpxsee
%{_bindir}/*
%{_datadir}/%{name}/*
%{_datadir}/applications/*
%{_datadir}/metainfo/*
%{_datadir}/icons/hicolor/*
%{_datadir}/mime/packages/*

%changelog
* Sat Apr 20 2024 tumic@cbox.cz
- Update to version 13.19
  * Added support for FIT course icons.
  * Use propper GUI icons on Qt>=6.7 (Windows & Mac).
  * Added support for GPX water temperature extension.
  * Multiple minor map fixes (IMG & Mapsforge).
* Sat Mar 23 2024 tumic@cbox.cz
- Update to version 13.18
  * Added support for arbitrary CRSs in GeoJSON files.
  * Added support for GeoJSON Coordinate Properties extension.
  * CRS database consolidation.
* Thu Mar  7 2024 tumic@cbox.cz
- Update to version 13.17
  * Added support for hillshading (IMG & Mapsforge maps).
  * Fixed broken "recent files" under KDE/Plasma6 style.
  * Minor fixes (Mapsforge, IMG and ENC maps).
* Tue Feb 13 2024 tumic@cbox.cz
- Update to version 13.16
  * Improved vector maps rendering.
  * Minor fixes.
* Mon Jan 22 2024 tumic@cbox.cz
- Update to version 13.15
  * Removed qt5compat dependency from Qt6 builds.
  * Multiple minor fixes (GUI).
* Tue Jan  2 2024 tumic@cbox.cz
- Update to version 13.14
  * Removed 4Umaps map source (map service discontinued).
  * Added mtbmap.cz map source.
  * Multiple minor map formats fixes/improvements (TrekBuddy, IMG).
* Mon Dec 18 2023 tumic@cbox.cz
- Update to version 13.13
  * Fixed broken map scale (ruler) on HiDPI maps.
  * Limit the overzoom to not produce huge tiles which break map
    rendering.
  * Increase the default pixmap cache size on Android to 384MB.
* Tue Dec 12 2023 tumic@cbox.cz
- Update to version 13.12
  * Added support for overzoom in MVT vector maps (MBTiles/online).
    QtPBFImageplugin version 3 required.
  * Vector (MVT) online maps now rendered asynchronous.
  * Fixed vector MBTiles not loading in Qt6 builds issue.
* Sun Nov 19 2023 tumic@cbox.cz
- Update to version 13.11
  * Added support for GPSDump WPT files.
  * Added "Open recent" menu.
  * Fixed broken menu items placement (Mac).
  * Huge MBTiles maps now load in a "geologically short" time.
  * Vector MBTiles maps now rendered asynchronous.
  * Fixed map bounds limiting.
* Sat Oct 28 2023 tumic@cbox.cz
- Update to version 13.10
  * New GUI icons that fit the current platform styles.
  * Added "Open directory" action for desktop systems.
  * Fixed/improved vector maps path label layout algorithm.
* Sun Sep 24 2023 tumic@cbox.cz
- Update to version 13.9
  * Fixed storing of WMTS tiles with file system incompatible tile
    matrix names.
  * Improved/fixed TrekBuddy maps/atlases support.
  * Improved ENC maps rendering style.
* Thu Sep  7 2023 tumic@cbox.cz
- Update to version 13.8
  * Added support for ENC atlases (catalogues).
  * Fixed broken "Use styles" persistent configuration.
  * Fixed broken opening of files from "content:" URLs (Android).
* Sun Aug 27 2023 tumic@cbox.cz
- Update to version 13.7
  * Fixed/improved map info background rendering settings.
  * Improved Mapsforge and ENC maps rendering.
  * Switched to Android SDK 33.
  * Added missing Windows quiet uninstaller entry.
* Sun Aug 13 2023 tumic@cbox.cz
- Update to version 13.6
  * Fixed Garmin GPI parser rejecting some valid files.
  * Improved Mapsforge and Garmin IMG maps rendering.
  * Added option to suppress file open errors.
* Sun Jul 30 2023 tumic@cbox.cz
- Update to version 13.5
  * Added graph pinch zooming.
  * Display one-way street info in IMG maps.
  * Use 512px tiles in Mapsforge maps rendering.
* Sat Jun 10 2023 tumic@cbox.cz
- Update to version 13.4
  * Extended Mapsforge render themes support.
  * Improved ENC maps rendering.
* Sun May 21 2023 tumic@cbox.cz
- Update to version 13.3
  * Improved vector maps zooming speed/performance.
  * Added support for custom HTTP headers in map tile requests.
  * Improved Mapsforge maps rendering.
* Fri May 12 2023 tumic@cbox.cz
- Update to version 13.2
  * Fixed crash on empty routes (introduced in 12.4).
  * Minor fixes.
* Fri May  5 2023 tumic@cbox.cz
- Update to version 13.1
  * Fixed wrong date info on tracks with segments.
  * Fixed display issues of Mapsforge and KMZ maps in HiDPI mode.
* Thu Apr 27 2023 tumic@cbox.cz
- Update to version 13.0
  * Reworked coordinate reference systems (CRS) handling.
  * Improved Mapsforge maps rendering performance.
  * Minor fixes.
* Mon Apr 10 2023 tumic@cbox.cz
- Update to version 12.4
  * Fixed/improved Mapsforge maps rendering.
  * Minor fixes.
* Sun Mar 26 2023 tumic@cbox.cz
- Update to version 12.3
  * Improved ENC maps rendering.
  * Minor fixes.
* Sat Mar  4 2023 tumic@cbox.cz
- Update to version 12.2
  * Fixed broken handling of IMG "multi-maps" (maps with overviews).
  * Marine maps rendering fixes & improvements (IMG & ENC).
  * Allow arbitrary large images (Qt6 only).
  * Added support for 0.5" (7201x7201) DEM tiles.
  * Made the DEM cache configurable.
* Sat Feb 18 2023 tumic@cbox.cz
- Update to version 12.1
  * Fixed areas rendering.
  * Fixed GeoJSON parser.
  * Fixed NMEA parser.
* Fri Feb 10 2023 tumic@cbox.cz
- Update to version 12.0
  * Android "desktop" integration.
  * Minor fixes.
* Fri Jan 27 2023 tumic@cbox.cz
- Update to version 11.12
  * Fixed broken parsing of KML tracks with empty coordinates.
  * Fixed bug where OziExplorer maps prevented loading any other
    maps from the same directory.
  * Improved marine maps (ENC, IMG) render style.
  * Added Korean localization.
* Sat Dec 10 2022 tumic@cbox.cz
- Update to version 11.11
  * Improved ENC maps render style.
* Sat Nov 26 2022 tumic@cbox.cz
- Update to version 11.10
  * Fixed broken Inland ECDIS rendering.
  * Improved ENC maps render style.
* Thu Nov 17 2022 tumic@cbox.cz
- Update to version 11.9
  * Improved ENC maps render style.
* Fri Nov 11 2022 tumic@cbox.cz
- Update to version 11.8
  * Fixed crash on ENC maps unload.
  * Improved ENC maps render style.
* Sun Nov  6 2022 tumic@cbox.cz
- Update to version 11.7
  * Added support for ENC charts.
  * Improved IMG maps marine style.
* Mon Oct 10 2022 tumic@cbox.cz
- Update to version 11.6
  * Fixed tracks/routes line style configuration (introduced in
    11.5).
  * Fixed KML StyleMap handling.
* Wed Sep 28 2022 tumic@cbox.cz
- Update to version 11.5
  * Added support for data styles.
  * Added Catalan localization.
  * Fixed KML gx::Track parsing.
  * Fixed broken map zoom 0 on HiDPI displays.
  * Updated USGS maps (added zoom 16).
* Sun Sep  4 2022 tumic@cbox.cz
- Update to version 11.4
  * Added support for KMZ data files.
  * Multiple KML format parser fixes and improvements.
  * Added support for non-SQL Orux maps.
* Thu Aug 11 2022 tumic@cbox.cz
- Update to version 11.3
  * Added support for Orux maps.
  * Android PDF/PNG export dialogues fixes/improvements.
* Sun Jul 31 2022 tumic@cbox.cz
- Update to version 11.2
  * Added support for Osmdroid SQLite maps.
  * Added support for GEMF maps.
  * Various minor map parsers fixes/improvements.
  * Multiple Android GUI fixes/improvements.
* Thu Jun  2 2022 tumic@cbox.cz
- Update to version 11.1
  * Fixed broken map zooming using the mouse wheel (introduced in
    11.0)
  * Now using asynchronous tiles rendering in IMG maps.
* Mon May 30 2022 tumic@cbox.cz
- Update to version 11.0
  * Added Android build.
  * Various map provider fixes (Mapsforge, IMG, JNX).
  * Fixed broken PNG/PDF exports on systems with HiDPI displays.
* Sun Apr 24 2022 tumic@cbox.cz
- Update to version 10.7
  * Multiple IMG maps loading/rendering fixes.
* Tue Apr 12 2022 tumic@cbox.cz
- Update to version 10.6
  * Improved marine charts rendering.
* Sun Mar 27 2022 tumic@cbox.cz
- Update to version 10.5
  * Improved handling of MBTiles maps with nonconsecutive zoom
    levels.
  * Fixed broken loading of some IMG maps.
  * Added a basic IMG nautical charts style.
* Mon Feb 14 2022 tumic@cbox.cz
- Update to version 10.4
  * Improved POI labels handling in IMG maps.
  * Fixed position/motion info output in exports/printing.
* Wed Feb  2 2022 tumic@cbox.cz
- Update to version 10.3
  * Improved/fixed GPI parser.
  * Significantly improved areas loading performance.
* Fri Jan 21 2022 tumic@cbox.cz
- Update to version 10.2
  * Improved/fixed TwoNav data files parser.
  * Prefer GPS locations when the positioning plugin provides
    multiple position sources.
  * Added a default DEM tiles download source.
  * Multiple minor fixes and enhancements.
* Sun Jan  2 2022 tumic@cbox.cz
- Update to version 10.1
  * Added support for TwoNav data files (TRK, RTE, WPT).
  * Extended waypoint icon set.
* Wed Dec  8 2021 tumic@cbox.cz
- Update to version 10.0
  * Added support for (GPS) positioning.
  * Added workaround for broken FIT files exported by Strava.
  * Fixed Mapsforge maps crash when Qt-SVG is missing.
* Wed Nov 17 2021 tumic@cbox.cz
- Update to version 9.12
  * Added support for QCT maps.
  * Fixed broken app icons install in "make install" on linux.
  * Minor IMG maps fixes and enhancements.
* Sun Oct 31 2021 tumic@cbox.cz
- Update to version 9.11
  * Switched to core5compat in Qt6 builds to support East Asian
    encodings where possible.
  * Fixed IMG map labels handling.
* Mon Oct 25 2021 tumic@cbox.cz
- Update to version 9.10
  * Added waypoint icons highlighting.
  * Various GPI parser fixes/improvements (icons related).
  * Added support for East Asian encodings in Garmin formats.
* Sat Oct 16 2021 tumic@cbox.cz
- Update to version 9.9
  * Fixed scroll wheel zooming on devices with "fine-resolution
    wheels".
* Wed Oct 13 2021 tumic@cbox.cz
- Update to version 9.8
  * Added support for Waypoint/POI icons.
  * Various minor bugfixes.
* Sun Sep 26 2021 tumic@cbox.cz
- Update to version 9.7
  * Added Chinese translation.
  * Added support for location FIT files.
  * Improved Mapsforge maps zoom performance.
  * Added DEM tiles overview.
  * Multiple settings handling fixes and enhancements.
* Sun Sep  5 2021 tumic@cbox.cz
- Update to version 9.6
  * Added support for downloading DEM files.
  * Fixed map tiles/files download timeout handling.
  * Various GUI polishing (mostly macOS).
* Sun Aug 22 2021 tumic@cbox.cz
- Update to version 9.5
  * Added support for ONmove (Decathlon) watch log files.
  * Fixed/improved IMG labels handling.
* Sun Aug  8 2021 tumic@cbox.cz
- Update to version 9.4
  * Rotate JPEG thumbnails according to EXIF data.
  * Fixed Mapsforge styles parsing/rendering.
  * Improved IMG maps performance.
* Sat Jul 17 2021 tumic@cbox.cz
- Update to version 9.3
  * Fixed crash with certain Mapsforge styles.
  * Removed the artificial POI zoom level limits in IMG maps.
  * Added initial open file paths configuration.
* Tue Jun 29 2021 tumic@cbox.cz
- Update to version 9.2
  * Added support for World-File georeferenced images.
  * Fixed SML and CSV parser issues.
* Sat May 29 2021 tumic@cbox.cz
- Update to version 9.1
  * Added support for TomTom OV2 and ITN files.
  * Various waypoint properties enhancements.
  * Mapsforge maps rendering fixes/improvements.
  * Some more minor fixes.
* Tue Apr 20 2021 tumic@cbox.cz
- Update to version 9.0
  * Added support for Mapsforge maps.
* Wed Mar 24 2021 tumic@cbox.cz
- Update to version 8.9
  * Preserve the directory structure when loading maps/POIs.
  * Improved areas rendering performance.
  * Added workaround for broken CRS urns used by Swisstopo.
  * Fixed possible crash on JNX maps.
* Mon Mar  1 2021 tumic@cbox.cz
- Update to version 8.8
  * Fixed disappearing marker with some graphs combinations.
* Sun Feb 21 2021 tumic@cbox.cz
- Update to version 8.7
  * Fixed broken marker date/coordinates when time graphs are
    selected.
  * Fixed window geometry save/restore.
  * Improved Full-screen layout.
* Sun Feb 14 2021 tumic@cbox.cz
- Update to version 8.6
  * Added support for Locus/OsmAnd/RMaps SQLite maps.
  * Add Coordinates display option to position info.
  * Minor AQM maps display fix.
* Mon Feb  8 2021 tumic@cbox.cz
- Update to version 8.5
  * Fixed crash on areas/polygons (introduced in 8.2).
* Sun Feb  7 2021 tumic@cbox.cz
- Update to version 8.4
  * Added support for AlpineQuest AQM maps.
  * Added position date display option.
  * IMG format compatability and performance improvements.
* Sat Jan 23 2021 tumic@cbox.cz
- Update to version 8.3
  * Fixed crash on empty paths (introduced in 8.2).
* Tue Jan 19 2021 tumic@cbox.cz
- Update to version 8.2
  * Fixed crash on broken KMZ maps.
  * Improved graph slider/path marker handling.
  * Minor UI/UX enhancements.
* Sat Jan  2 2021 tumic@cbox.cz
- Update to version 8.1
  * Fixed digital zoom on OS X.
  * Fixed Qt6 Release build.
  * Added support for ZIPed DEM files.
  * Minor fixes.
* Tue Dec 29 2020 tumic@cbox.cz
- Update to version 8.0
  * Added support for KMZ maps.
  * Added Qt6 support, dropped Qt4 support.
* Wed Dec 16 2020 tumic@cbox.cz
- Update to version 7.38
  * Maps can now be opened like data files (program parameter,
    drag&drop, ...) and with overviews.
  * Added support for BSB nautical charts.
  * Added support for polyconic projections.
* Wed Nov 25 2020 tumic@cbox.cz
- Update to version 7.37
  * Added "copy coordinates to clipboard" feature.
  * Improved graphs zooming.
  * Various minor GUI tweaks/fixes.
  * Improved IMG maps drawing performance.
  * Improved GeoTIFF compatability.
* Wed Nov 11 2020 tumic@cbox.cz
- Update to version 7.36
  * IMG format fixes/improvements (mostly labels related).
  * Added workaround for broken IMG maps produced by mkgmap.
  * Added workaround for broken FIT files produced by gpsbabel.
* Tue Oct 27 2020 tumic@cbox.cz
- Update to version 7.35
  * IMG format compatability, performance and layout improvements.
  * Fixed CRS entries parsing (WMS, WMTS)
  * Various minor bug fixes.
* Fri Oct  9 2020 tumic@cbox.cz
- Update to version 7.34
  * Fixed application icons paths.
* Wed Oct  7 2020 tumic@cbox.cz
- Update to version 7.33
  * Added PNG export.
* Mon Sep 21 2020 tumic@cbox.cz
- Update to version 7.32
  * Configurable (GPX) segments handling.
  * Fixed TCX trackpoint extensions parsing.
  * Some more IMG format compatability improvements.
  * "Multi-size" application icons.
* Tue Jun 30 2020 tumic@cbox.cz
- Update to version 7.31
  * Added Italian translation.
  * Fixed build with Qt 5 versions <= 5.5.
  * Various IMG format compatability and performance improvements.
* Sat May 30 2020 tumic@cbox.cz
- Update to version 7.30
  * Added time zone configuration.
  * Added support for IMG map overlays.
  * Reverted to the original (<=7.28) outlier threshold.
  * Updated Antarctica map URL.
  * Minor fixes (KML, CRS format).
* Sun Apr 19 2020 tumic@cbox.cz
- Update to version 7.29
  * Added support for FIT course points.
  * Minor IMG maps fixes/tweaks.
* Sun Apr  5 2020 tumic@cbox.cz
- Update to version 7.28
  * Fixed broken graph color change when secondary graphs present.
  * Fixed broken map enable condition (selecting such map crashes
    GPXSee).
* Sat Mar 28 2020 tumic@cbox.cz
- Update to version 7.27
  * Fixed builds with -Werror=format-security (Fedora, RHEL,
    Mageia). No real issue.
* Sat Mar 28 2020 tumic@cbox.cz
- Update to version 7.26
  * Enable simultaneous display of GPS and DEM data.
  * Asynchronous WMS/WMTS map loading (fixes crash on OS X).
  * Various minor bug fixes.
* Wed Mar  4 2020 tumic@cbox.cz
- Update to version 7.25
  * Added missing OnlineResources URLs handling in WMS maps.
  * A better WMS format parameter handling (partialy broken in
    7.24)
* Sun Mar  1 2020 tumic@cbox.cz
- Update to version 7.24
  * Multiple WMS maps fixes.
* Mon Feb 17 2020 tumic@cbox.cz
- Update to version 7.23
  * Fixed various IMG maps rendering issues.
  * Improved the default IMG map style.
* Thu Feb 13 2020 tumic@cbox.cz
- Update to version 7.22
  * Fixed loading of GMAP maps when Garmin BaseCamp has associated
    them (OS X issue).
* Wed Feb 12 2020 tumic@cbox.cz
- Update to version 7.21
  * Added support for Garmin GMAP maps.
  * Various IMG/GMAP maps fixes/improvements.
  * Hungarian localization.
* Sun Jan 26 2020 tumic@cbox.cz
- Update to version 7.20
  * Added support for Suunto SML files.
  * Various IMG maps improvements.
* Sun Jan 12 2020 tumic@cbox.cz
- Update to version 7.19
  * Fixed/improved pause detection.
  * Fixed buffer overflow in GPI parser.
  * OpenStreetMap and 4UMaps URL changes.
  * Minor IMG file format reader fixes/improvements.
  * Fixed/improved tooltip/popups handling.
  * Translations updates.
* Fri Nov 15 2019 tumic@cbox.cz
- Update to version 7.18
  * Added support for waypoint addresses.
  * Improved pause detection.
  * Improved GPI support (images, safety cameras).
  * Added Ukrainian translation.
* Sat Nov  2 2019 tumic@cbox.cz
- Update to version 7.17
  * Fixed program crash on empty GPX segment.
  * Fixed broken DEM value reading on S/W coordinates.
  * Various GPI parser fixes & improvements.
* Mon Oct 28 2019 tumic@cbox.cz
- Update to version 7.16
  * Added support for Garmin GPI files.
  * Hyperlink + copy&paste enabled tool tips.
  * Various minor bug fixes in data loading.
* Sat Oct  5 2019 tumic@cbox.cz
- Update to version 7.15
  * Fixed broken align of zoom level 0 with tiles of a different
    size than 256px.
  * Increased the default tile cache size value to 256MB.
  * IMG maps text layout tweaking and optimization.
* Sun Sep 29 2019 tumic@cbox.cz
- Update to version 7.14
  * Added support for enchanced altitude and speed records in FIT
    files.
  * Added support for pseudo-NT IMG maps (e.g. TopoHispania).
* Sun Sep  1 2019 tumic@cbox.cz
- Update to version 7.13
  * Added support for graph zooming.
  * Several minor bug fixes.
* Sat Aug 17 2019 tumic@cbox.cz
- Update to version 7.12
  * Added support for SeeYou CUP files.
  * Added support for Geographic 2D projection in vector maps.
  * Fixed lat/lon reference parsing in big endian EXIF entries.
* Thu Jul 18 2019 tumic@cbox.cz
- Update to version 7.11
  * Improved IMG maps loading performance and memory footprint.
  * Improved road shields layout on IMG maps.
* Sun Jul  7 2019 tumic@cbox.cz
- Update to version 7.10
  * Various IMG maps fixes and improvements.
* Sat Jun 15 2019 tumic@cbox.cz
- Update to version 7.9
  * Removed the annoying map view re-zooming on window resize.
  * Improved POI handling and text rendering in IMG maps.
* Thu May 30 2019 tumic@cbox.cz
- Update to version 7.8
  * Added support for QuadTiles maps.
  * Added (optional) km/mi path markers.
  * Fixed broken IMG maps after print/PDF export.
  * Fixed broken zoom fit on IMG maps.
  * Fixed broken WMS scale denominators to zoom levels transition.
* Sat May 18 2019 tumic@cbox.cz
- Update to version 7.7
  * Fixed build & display issues with Qt < 5.4.
  * Added support for vector maps projection setting.
  * Added support for user defined TYP files for Garmin IMG maps.
  * Removed obsolete "Always show the map" setting.
* Sun May 12 2019 tumic@cbox.cz
- Update to version 7.6
  * Added support for Garmin IMG maps.
  * Fixed coordinates info display issues.
  * Fixed rendering of large areas using OpenGL.
  * Fixed broken speed type switch.
* Sat Mar 16 2019 tumic@cbox.cz
- Update to version 7.5
  * Added support for geotagged JPEG images.
* Sun Mar 10 2019 tumic@cbox.cz
- Update to version 7.4
  * Added support for TwoNav RMaps.
  * Fixed broken projection equations (multiple corner cases).
  * Fixed IGC date handling issues.
* Tue Feb 19 2019 tumic@cbox.cz
- Update to version 7.3
  * Added support for area (polygon) objects.
  * Added support for track segments.
  * Added support for oblique stereographic projections.
  * Added the "Show cursor coordinates" option.
  * Added Portuguese (Brazil) localization.
  * Minor bug fixes (GPX parser, GUI).
* Mon Jan 28 2019 tumic@cbox.cz
- Update to version 7.2
  * Added support for DEM data (SRTM HGT files).
  * Improved look&feel in dark styles.
  * Added support for polar stereographic projections + Antarctica
    map.
  * Added support for GeoJSON files.
  * Added Spanish localization.
* Wed Jan  2 2019 tumic@cbox.cz
- Update to version 7.1
  * Fixed build with Qt5 <= 5.4
  * Minor bug fixes & updates (TCX, localization)
* Sat Dec  8 2018 tumic@cbox.cz
- Update to version 7.0
  * Added support for PBF vector maps (requires QtPbfImagePlugin).
  * Changed user data/config paths locations.
  * Added Turkish localization.
  * Minor bug fixes (WMTS, graphs)
* Sat Oct 13 2018 tumic@cbox.cz
- Update to version 6.3
  * Fixed broken OSM maps non-default bounds handling.
  * Fixed broken cleanup on exit (introduced in 6.1).
  * Added Danish localization.
* Sun Oct  7 2018 tumic@cbox.cz
- Update to version 6.2
  * Fixed Norwegian localization language code.
* Sun Oct  7 2018 tumic@cbox.cz
- Update to version 6.1
  * Fixed broken tiles rendering on OSM/TMS map borders (broken in
    5.18).
  * Fixed "enable HTTP2" configuration handling.
  * Added Norwegian localization.
* Sun Sep 23 2018 tumic@cbox.cz
- Update to version 6.0
  * Added MBTiles maps support.
  * Added TMS maps support.
  * Added support for local file URLs (OSM, TMS, WMTS maps).
  * Minor bugfixes (localization, WMTS, date-line crossing).
* Sat Sep 15 2018 tumic@cbox.cz
- Update to version 5.18
  * Made the HiDPI display mode (of non-HiDPI maps) configurable.
  * Long path segments now displayed using great circle paths.
  * Fixed IGC parser (new date header format support).
  * Fixed broken zoom level 0 handling.
  * Fixed POI search algorithm.
  * Fixed Garmin CSV parser (wrong coordinates order).
  * Some more minor bugfixes.
* Sat Aug 18 2018 tumic@cbox.cz
- Update to version 5.17
  * Added support for HiDPI/Retina displays & maps.
  * Added support for SIGMA SPORT SLF files.
  * Added support for Geocaching.com LOC files.
* Wed Aug  8 2018 jengelh@inai.de
- Fixup grammar of summary.
* Wed Aug  8 2018 tumic@cbox.cz
- Update to version 5.16
  * Added statistics report.
  * Added support for HTTP/2 (Qt>=5.10.1)
  * Various minor bugfixes.
* Tue Jul  3 2018 tumic@cbox.cz
- Update to version 5.15
  * Added gear ratio/shifts graphs (Shimano Di2).
  * Fixed FIT parser crash.
  * Added support for obscure Bryton Rider FIT files.
  * Some more minor bugfixes.
* Sat Jun 23 2018 tumic@cbox.cz
- Update to version 5.14
  * Improved outlier detection (now based on acceleration rather
    than speed)
  * Fixed broken distance computation when outlier detection was
    enabled.
  * Added speed data source setting.
  * Several minor bugfixes.
* Tue May 29 2018 tumic@cbox.cz
- Update to version 5.13
  * Fixed broken automatic loading of OziExplorer maps (introduced
    in 5.12)
  * Added support for Krovak projections (EPSG:1041 and EPSG:9819)
* Fri May 25 2018 tumic@cbox.cz
- Update to version 5.12
  * Added support for Garmin JNX maps.
  * Added support for GPX Garmin route extension.
  * Several performance improvements.
* Mon May 14 2018 tumic@cbox.cz
- Update to version 5.11
  * Added support for EPSG:9606 and 9607 datum transformations.
  * Added support for Mercator projection (the real one).
  * Updated the GCS & PCS files.
  * Fixed LCC2 GeoTIFF images loading.
  * Fixed broken time-based graphs for files with duplicit
    timestamps.
* Wed May  9 2018 tumic@cbox.cz
- Update to version 5.10
  * Improved track loading performance.
  * Improved network/server error handling.
  * Added missing EST97 GCS/PCS.
  * Several minor bugfixes and improvements.
* Thu Apr 19 2018 tumic@cbox.cz
- Update to version 5.9
  * Fixed HTTP redirects handling.
  * Proper fix of the zoom changes/offset bugs (resolved only
    partialy in 5.8).
* Wed Apr 18 2018 tumic@cbox.cz
- Update to version 5.8
  * Fixed the irritating map zoom changes on OSM maps switching and
    the 1px map center offset bug.
  * Added Polish translation.
* Tue Apr 17 2018 tumic@cbox.cz
- Update to version 5.7
  * Added OziExplorer data files (plt, rte, wpt) support.
* Sun Apr  8 2018 tumic@cbox.cz
- Update to version 5.6
  * Added WMS support.
  * Several minor bugfixes and improvements (mostly WMTS).
* Tue Mar 20 2018 tumic@cbox.cz
- Update to version 5.5
  * Fixed deadlocks caused by infinite HTTP timeout.
  * Several minor bugfixes.
* Sun Mar 11 2018 tumic@cbox.cz
- Update to version 5.4
  * Added pace info.
  * Added support for EPSG 21781 PCS (Swiss grid).
  * Added missing WMTS dimensions handling.
  * Fixed broken zoom rectangle computation.
  * Fixed swapped GeoTIFF LCC1 and LCC2 projection codes.
  * Fixed loading of WGS84 GeoTIFF images defined using
    the ellipsoid only.
  * Fixed broken (case-sensitive) WMTS parameters handling.
* Thu Mar  1 2018 tumic@cbox.cz
- Update to version 5.3
  * Added support for WMTS maps.
  * Fixed Lambert azimuthal equal area projection.
  * Improved scale computation on offline maps.
  * Added some more GCS/PCS definitions.
  * Fixed invalid memory access.
* Sat Feb 17 2018 tumic@cbox.cz
- Update to version 5.2
  * Fixed broken GeoTIFF (Web) Mercator projection.
  * Several minor bug fixes.
* Mon Feb 12 2018 tumic@cbox.cz
- Update to version 5.1
  * Fixed crash during static data initialization.
  * Added coordinates format setting.
  * Added nautical units setting.
* Sat Feb 10 2018 tumic@cbox.cz
- Update to version 5.0
  * Added support for GeoTIFF images.
  * Online map sources are now defined using XML files.
  * Added Finnish, French and Russian localization.
* Mon Jan  8 2018 tumic@cbox.cz
- Update to version 4.19
  * Fixed missing cached content cleanup causing huge draw areas
    (causing system memory exhaustion) issue.
* Sat Jan  6 2018 tumic@cbox.cz
- Update to version 4.18
  * Fixed broaken A records parsing in IGC files.
  * Added support for negative altitudes in IGC files.
* Sat Dec  9 2017 tumic@cbox.cz
- Update to version 4.17
  * Added support for Lambert Azimuthal Equal Area projections.
  * Added support for map viewing without GPS log files loaded.
  * Added slider/marker color setting.
  * Fixed scene centering issue.
  * Fixed offline map scale computation issue.
  * Fixed some corner case map drawing issues.
* Wed Oct 18 2017 tumic@cbox.cz
- Update to version 4.16
  * Fixed broken loading of KML files with folder elements outside
    document element.
  * Added support for KML files with multitracks.
  * Added support for Temperature, Cadence and Heartrate in KML
    files.
  * Added support for TCX multi-sport activities.
* Fri Oct  6 2017 tumic@cbox.cz
- Update to version 4.15
  * Fixed the 1px content offset on zoom/map change issue.
  * Improved graph slider info.
  * Graph items are now selecteble like path items (+ tool tips).
* Fri Sep 15 2017 tumic@cbox.cz
- Update to version 4.14
  * Fixed broken parsing of TCX files with heart rate data.
  * Fixed invalid memory access in NMEA parser.
  * Fixed broken units setting for cadence, heart rate and power
    graphs.
  * Added support for limiting the maximal zoom level of online map
    sources.
  * Added waypoints/POI size/color settings and map background
    color settings.
  * Adjusted the scale bar (text) size to the remaining content
    in print/PDF export output.
* Sun Sep  3 2017 tumic@cbox.cz
- Update to version 4.13
  * Added support for high-resolution printing.
* Thu Aug 24 2017 tumic@cbox.cz
- Update to version 4.12
  * Fixed broken LCC projection on southern hemisphere.
  * Added support for France I-IV and VICGRID/VICGRID94 projections.
  * Added map opacity (brightness) setting.
  * Added 4UMaps to map sources.
* Tue Aug 15 2017 tumic@cbox.cz
- Update to version 4.11
  * Fixed QT4 build.
* Tue Aug 15 2017 tumic@cbox.cz
- Update to version 4.10
  * Added support for OZF zoom levels.
  * Added support for maps with only 2 reference points.
  * Various map loading/displaying improvements.
* Tue Jul 11 2017 tumic@cbox.cz
- Update to version 4.9
  * Improved map switching (no more track resizing on map change).
  * Improved TARed Trekbuddy maps loading (now using TMI index
    files if available).
  * Optimized POI handling.
* Thu May 25 2017 tumic@cbox.cz
- Update to version 4.8
  * Added data filtering settings.
  * Fixed broken units handling in track info tooltips.
* Tue May  9 2017 tumic@cbox.cz
- Update to version 4.7
  * Fixed broken offline maps on southern hemisphere.
  * Fixed broken UTM zone setup on some offline maps.
  * Added support for OZF3 files.
  * Added support for Albers Equal-Area projection.
  * Added support for offline maps with projections defined as
    British, Irish and Swedish grid and NZTM2000.
* Tue May  2 2017 tumic@cbox.cz
- Update to version 4.6
  * Fixed broken PDF export/printing (broken map scale/waypoints
    size).
  * Improved path projection performance when an atlas is used.
* Sun Apr 23 2017 tumic@cbox.cz
- Update to version 4.5
  * Added support for "runtime" loading of offline maps.
  * Fixed atlas zoom fitting.
  * Fixed various minor offline map loading issues.
* Mon Apr 17 2017 tumic@cbox.cz
- Update to version 4.4
  * Added support for ozf2 image files.
  * Added full support for non-WGS84 datum based offline maps.
  * Added German localization.
* Wed Apr 12 2017 tumic@cbox.cz
- Update to version 4.3
  * Fixed missing cached content cleanup causing huge draw areas
    (causing memory exhaustion) issue.
  * Fixed map file defined datum not set for UTM maps issue.
* Thu Apr  6 2017 tumic@cbox.cz
- Update to version 4.2
  * Added digital zoom.
  * Fixed atlas map fitting algorithm.
  * Completed Swedish translation.
* Sun Apr  2 2017 tumic@cbox.cz
- Update to version 4.1
  * Added support for Lambert conformal conic projection.
* Sat Apr  1 2017 tumic@cbox.cz
- Update to version 4.0
  * Added support for offline maps.
  * Fixed zoom issues on touchpads.
* Mon Feb 13 2017 tumic@cbox.cz
- Update to version 3.9
  * Fixed broken POI radius computation.
  * Added moving time info.
  * Improved pause detection/handling.
* Tue Jan 24 2017 tumic@cbox.cz
- Update to version 3.8
  * Fixed graph info not redrawing issue.
  * Added Swedish localization.
* Mon Jan 23 2017 tumic@cbox.cz
- Update to version 3.7
  * Fixed tile downloading issues (multiple downloads, redirect
    loop).
  * Enabled free map scroll.
* Tue Dec 20 2016 tumic@cbox.cz
- Update to version 3.5
  * Fixed broken NMEA latitude parsing.
  * Added print/export options.
* Sat Dec 10 2016 tumic@cbox.cz
- Update to version 3.4
  * Fixed QT5 < 5.4 builds (Debian 8).
* Fri Dec  9 2016 tumic@cbox.cz
- Update to version 3.3
  * Added options dialog with basic appearance settings.
  * Added OpenGL support.
* Tue Nov 22 2016 tumic@cbox.cz
- Update to version 3.2
  * Added support for NMEA files.
  * Fixed path marker inaccuracy bug.
* Sat Nov 12 2016 tumic@cbox.cz
- Update to version 3.1
  * Added support for IGC files.
  * Fixed zoom level computation bugs.
* Mon Nov  7 2016 tumic@cbox.cz
- Update to version 3.0
  * Added support for TCX, KML and FIT files.
  * Added cadence and power graphs.
  * Improved outlier detection (now also applies to track points).
  * GUI polishing.
  * Improved print output.
* Sun Oct 16 2016 tumic@cbox.cz
- Update to version 2.20
  * Added support for drag&drop.
  * Fixed graph line distortion in PDF output.
  * Fixed POI loading performance issue.
  * GUI polishing.
* Wed Sep 28 2016 tumic@cbox.cz
- Update to version 2.19
  * Added time-based graphs.
  * Added track/graph highlighting (on track hover).
  * Added support for proxy connections (using the system-defined
    proxy).
  * Fixed PDF output in QT4 builds.
* Wed Aug 31 2016 tumic@cbox.cz
- Update to version 2.18
  * Added support for GPX routes.
  * Added various data display options.
  * Improved performance.
* Wed Aug  3 2016 tumic@cbox.cz
- Update to version 2.17
  * Added waypoint/track info tooltips.
  * Improved POI handling.
* Thu Jun 16 2016 tumic@cbox.cz
- Update to version 2.16
  * Fixed infinite download loop on HTTP redirects (and broken
    images).
  * Fixed handling of GPX files with inconsistent track point
    entries.
  * Added support for temperature graphs.
* Sat May 28 2016 tumic@cbox.cz
- Update to version 2.14
  * Added print support.
  * Many fixes & improvements in PDF export (e.g. map support).
* Tue May  3 2016 tumic@cbox.cz
- Update to version 2.13
  * Fixed broken opening of non-ASCII named files as program
    arguments.
  * File info in window title.
  * Persistent program settings.
* Thu Apr 14 2016 tumic@cbox.cz
- Update to version 2.12
  * Added fullscreen mode.
  * Polished GUI.
* Sat Apr  2 2016 tumic@cbox.cz
- Update to version 2.11
  * Added "clear tile cache" option.
  * Lots of minor bug fixes and enhancements.
* Fri Mar 25 2016 tumic@cbox.cz
- Update to version 2.10
  * Added heart rate graphs.
  * Polished GUI.
  * Redesigned map/POI data sources handling.
  * Lots of minor bug fixes and enhancements.
* Sun Mar 20 2016 tumic@cbox.cz
- Update to version 2.9
  * Added support for displaying waypoints.
  * Minor bug fixes and enhancements.
* Sun Mar  6 2016 tumic@cbox.cz
- Update to version 2.8
  * Improved POI files control.
  * Minor bug fixes and enhancements.
* Sat Feb 13 2016 tumic@cbox.cz
- Update to version 2.7
  * Added default map sources (OSM, Thunderforest).
  * Added support for POIs in GPX format.
  * Added support for GPX files with multiple tracks.
* Wed Feb  3 2016 tumic@cbox.cz
- Update to version 2.6
  * Added map scale info.
  * Improved PDF export.
* Sun Dec 20 2015 tumic@cbox.cz
- Update to version 2.5
  * Added support for imperial units.
  * Fixed track view resizing issues.
